PyXMake Developer Guide: PyXMake.API.Frontend Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | List of all members
PyXMake.API.Frontend Class Reference

Class instance to define PyXMake's web API instance. More...

Inheritance diagram for PyXMake.API.Frontend:

## Public Member Functions
| __init__ (self, *args, **kwargs)
Public Member Functions inherited from PyXMake.API.Base
| RedirectException (self, url)
| StaticFiles (self, url, path, index="index.html", html=True)
| mount (self, *args)
| include (self, *args)
| create (self)
| run (self, Hostname=str(platform.node()), PortID=8020)
Public Member Functions inherited from PyXMake.API.Backend
Public Member Functions inherited from PyXMake.Tools.Utility.AbstractBase
| __new__ (cls, *args, **kwargs)
| recover (cls, *args)
| classify (cls, *args, **kwargs)
| jsonify (self)
| update (self, **kwargs)
| __repr__ (self)
| __str__ (self)
| __getstate__ (self)
| __setstate__ (self, _dict)

## Public Attributes
str | APIObjectKind = "Frontend"
| APIMeta = kwargs.get("Meta", {})
list | APITags
dict | APISwagger = {"defaultModelsExpandDepth": -1}
| API
| APIHost = kwargs.get("HostID",socket.gethostname())
| APIPort = kwargs.get("PortID",str(8020))
str | APIBase = ":".join([self.APIHost,self.APIPort])
Public Attributes inherited from PyXMake.API.Base
| API = APIRouter();
str | APIObjectKind = "Base"
| Router
Public Attributes inherited from PyXMake.API.Backend
str | APIObjectKind = "Backend"
| APIBase

## Additional Inherited Members
Static Public Member Functions inherited from PyXMake.Tools.Utility.AbstractBase
| __getbase__ (base, cls)

## Detailed Description

Class instance to define PyXMake's web API instance.

    Class instance to define PyXMake's server instance for a web API.

## Constructor & Destructor Documentation

## ◆ __init__()

PyXMake.API.Frontend.__init__ | ( |  | self,
|  | * | args,
|  | ** | kwargs )

    Initialization of PyXMake's Frontend API.

Reimplemented from PyXMake.API.Base.

Definition at line 1904 of file __init__.py.

## Member Data Documentation

## ◆ API

PyXMake.API.Frontend.API

Initial value:
= FastAPI(title="PyXMake API",
# Use internal package version instead of global package number. Kept for backwards compatibility
version = getattr(PyXMake,"__version__", self.APIMeta.pop("version","1.0.0")),
description ="Simplifying complex compilations",
docs_url = self.__pyx_api_delimn.join(["",str(PyXMake.__name__),"api","documentation"]),
swagger_ui_parameters = self.APISwagger, openapi_tags = self.APITags, **self.APIMeta)

Definition at line 1924 of file __init__.py.

## ◆ APIBase

str PyXMake.API.Frontend.APIBase = ":".join([self.APIHost,self.APIPort])

Definition at line 1934 of file __init__.py.

## ◆ APIHost

PyXMake.API.Frontend.APIHost = kwargs.get("HostID",socket.gethostname())

Definition at line 1932 of file __init__.py.

## ◆ APIMeta

PyXMake.API.Frontend.APIMeta = kwargs.get("Meta", {})

Definition at line 1912 of file __init__.py.

## ◆ APIObjectKind

str PyXMake.API.Frontend.APIObjectKind = "Frontend"

Definition at line 1909 of file __init__.py.

## ◆ APIPort

PyXMake.API.Frontend.APIPort = kwargs.get("PortID",str(8020))

Definition at line 1933 of file __init__.py.

## ◆ APISwagger

dict PyXMake.API.Frontend.APISwagger = {"defaultModelsExpandDepth": -1}

Definition at line 1921 of file __init__.py.

## ◆ APITags

list PyXMake.API.Frontend.APITags

Initial value:
= [
{"name": self.__pyx_guide,"description": "Operations to obtain server documentation."},
{"name": self.__pyx_interface,"description": "Operations for all users."},
{"name": self.__pyx_professional,"description": "Operations for experienced users and developers."}]

Definition at line 1915 of file __init__.py.

The documentation for this class was generated from the following file:

- src/PyXMake/API/__init__.py